@@ -1,7 +1,6 @@
 import re
 
 import dask.dataframe as dd
-
 from dagster import Any, Bool, Field, Float, Int, Permissive, Shape, String
 
 
@@ -123,7 +122,9 @@ DataFrameUtilities = {
                     "divisions": Field(
                         Any,
                         is_required=False,
-                        description="Known values on which to separate index values of the partitions.",
+                        description=(
+                            "Known values on which to separate index values of the partitions."
+                        ),
                     ),
                 }
             ),
